package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````Y!4``#0````X@0````0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````J'P`
M`*A\```%```````!``$```#`?0``P'T!`,!]`0!\`@``K!(```8```````$`
M`@```,A]``#(?0$`R'T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3`?0``P'T!`,!]`0!``@``0`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$\````(````"```
M``&0$``E0`2`*(`0!:"&4(2``0``"R`$C3B`$D&*!`@(3P```%````!4````
M60```%H```!A````8@```&,`````````90```&8`````````9P```&@```!K
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!6.^7>;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FH:GE"_VE<;H^#[20``````````
M````````````````@!`````````#``<```````"``0```````P`1``$`````
M`````````!(```#F`0`````````````2````"0``````````````$0````P"
M`````````````!$```"(`0`````````````2````$```````````````$@``
M`,4!`````````````!(````8```````````````2````'P``````````````
M$@```!D"`````````````!(```#1`0`````````````2````*```````````
M````(````$T#`````````````"$```!````````````````2````1@``````
M````````$@```$T``````````````!(````:`P`````````````2````"P,`
M````````````$@```+4"`````````````!(```!4```````````````2````
M5@(`````````````$@```%L``````````````!(```#J`@`````````````2
M````8@``````````````$@```&H``````````````!(```#3`@``````````
M```2````<@``````````````$@```'L``````````````"`````$`P``````
M```````2````EP``````````````$@```)P``````````````!(````J`@``
M```````````1````\0(`````````````$@```(,"`````````````!(```"C
M```````````````2````=0(`````````````$@```)$#`````````````!(`
M``!,`P`````````````1````IP(`````````````$@```#D#````````````
M`!(````U`@`````````````2````3@,`````````````$0```*H`````````
M`````!(````Q`P`````````````2````LP``````````````$0```)8!````
M`````````!(```#%```````````````B````U```````````````(````.H`
M`````````````!(```#\`@`````````````2````DP(`````````````$@``
M`.\``````````````!(```#U```````````````@````W@(`````````````
M$@````\!`````````````!(```"V`0`````````````2````%`$`````````
M````$@```,,"`````````````!(````:`0`````````````2````I0$`````
M````````$@```"@!`````````````!(````Y`0`````````````2````40(`
M````````````$@```&("`````````````!(````_`0`````````````2````
MG`(`````````````$@```"H#`````````````!(```!.`0`````````````2
M````(@,`````````````$@```&(!`````````````!(```!,`@``````````
M```2````]`$`````````````$@```&D!`````````````!(```!P`0``````
M```````2````2P,`````````````(0```($!`````````````!(```"1!```
M;)`!```````0`!(`1@,``)03``!0`@``$@`)``8"``!,/P``!````!(`"@#3
M`P``2"8``/P&```2``D`H00``-`P``!8````$@`)`+`#``",'P``!````!(`
M"0!%!```@!````0````2``<`]@,``$0M``",`P``$@`)`$L$```\@`$`````
M`!``$@!Y!```D!\``"P"```2``D`+@0``#R``0``````$``2`,$#``"4)0``
MM````!(`"0#@`P``=!T``%P````2``D`Z`,``!0E``!H````$@`)``P$``#0
M/```1`$``!(`"0`A!```O"$``!P````2``D`.@0``&R0`0``````$``2`)P$
M``!LD`$``````!``$@!V`P``"!8``&0````2``D`600``-@A```(`0``$@`)
M`!<$```X@`$`!````!$`$0!R!```/(`!```````0`!$`,P0``.05````````
M$@`)`$($``"`/```4````!(`"0!_`P``?"4``!@````2``D`F@,``#P>``!0
M`0``$@`)`(8$```4/@``.`$``!(`"0"0!```;)`!```````0`!(`900``.`B
M```T`@``$@`)``!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!S;G!R
M:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`<W1R
M8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`&-L;W-E9&ER`%])
M5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T<G-T<@!S=')C:'(`
M<F5A9&QI;FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?9FEN86QI>F4`7U]R
M96=I<W1E<E]F<F%M95]I;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E<E1-
M0VQO;F5486)L90!R96%D`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E<G)N;U]L
M;V-A=&EO;@!M:V1I<@!?7VQS=&%T7W1I;64V-`!P=&AR96%D7V=E='-P96-I
M9FEC`&UE;6-P>0!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E
M<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT
M`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?
M=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!097)L7V-R;V%K
M7VUE;6]R>5]W<F%P`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R
M:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R
M=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O
M=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E
M<FQ?86QL;V,`9G!R:6YT9@!S=')D=7``<'1H<F5A9%]A=&9O<FL`<F5A9&1I
M<@!S<')I;G1F`'-T<G1O:P!S=')N8W!Y`%]?;&EB8U]S=&%R=%]M86EN`%]?
M7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C+FUU<VPM87)M:&8N<V\N,0!?<W1A
M<G1?8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?;&EB<&%T:`!P
M87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L
M<U]005)?0D]/5`!S:&%?=7!D871E`&UY7W!A<E]P;`!P87)?8F%S96YA;64`
M7U]B<W-?<W1A<G0`7U]E;F1?7P!S:&%?:6YI=`!?7V)S<U]S=&%R=%]?`'!A
M<E]D:7)N86UE`'!A<E]I;FET7V5N=@!?961A=&$`<&%R7V9I;F1P<F]G`'-H
M85]F:6YA;`!?7V)S<U]E;F1?7P!?96YD`'!A<E]C;&5A;G5P`"]U<W(O;&EB
M+W!E<FPU+V-O<F5?<&5R;"]#3U)%``#`?0$`%P```,1]`0`7````P'\!`!<`
M``#,?P$`%P```-A_`0`7`````(`!`!<````(@`$`%P````R``0`7````%(`!
M`!<````8@`$`%P```!R``0`7````((`!`!<````D@`$`%P```"R``0`7````
M,(`!`!<````X@`$`%P```,1_`0`5!0``R'\!`!4&``#0?P$`%0X``-1_`0`5
M'@``W'\!`!4B``#@?P$`%2P``.1_`0`5+P``Z'\!`!4Q``#L?P$`%3(``/!_
M`0`5-P``]'\!`!4\``#X?P$`%3X``/Q_`0`50@``Q'X!`!8#``#(?@$`%@0`
M`,Q^`0`6!P``T'X!`!8(``#4?@$`%@D``-A^`0`6"@``W'X!`!8+``#@?@$`
M%@P``.1^`0`6#0``Z'X!`!8.``#L?@$`%A```/!^`0`6$0``]'X!`!82``#X
M?@$`%A,``/Q^`0`6%````'\!`!85```$?P$`%A8```A_`0`6%P``#'\!`!88
M```0?P$`%AD``!1_`0`6&@``&'\!`!8;```<?P$`%AP``"!_`0`6'0``)'\!
M`!8?```H?P$`%B```"Q_`0`6(0``,'\!`!8C```T?P$`%B0``#A_`0`6)0``
M/'\!`!8F``!`?P$`%B<``$1_`0`6*0``2'\!`!8J``!,?P$`%BL``%!_`0`6
M+0``5'\!`!8N``!8?P$`%C```%Q_`0`6,0``8'\!`!8R``!D?P$`%C,``&A_
M`0`6-```;'\!`!8U``!P?P$`%C8``'1_`0`6.```>'\!`!8Y``!\?P$`%CH`
M`(!_`0`6.P``A'\!`!8]``"(?P$`%C\``(Q_`0`60```D'\!`!9!``"4?P$`
M%D,``)A_`0`61```G'\!`!9%``"@?P$`%D8``*1_`0`61P``J'\!`!9(``"L
M?P$`%DD``+!_`0`62@``M'\!`!9+``"X?P$`%DP``+Q_`0`63@```4`MZ0%`
MO>@>_R_A!.`MY03@G^4.X(_@"/"^Y1QN`0``QH_B%LJ,XAS^O.4`QH_B%LJ,
MXA3^O.4`QH_B%LJ,X@S^O.4`QH_B%LJ,X@3^O.4`QH_B%LJ,XOS]O.4`QH_B
M%LJ,XO3]O.4`QH_B%LJ,XNS]O.4`QH_B%LJ,XN3]O.4`QH_B%LJ,XMS]O.4`
MQH_B%LJ,XM3]O.4`QH_B%LJ,XLS]O.4`QH_B%LJ,XL3]O.4`QH_B%LJ,XKS]
MO.4`QH_B%LJ,XK3]O.4`QH_B%LJ,XJS]O.4`QH_B%LJ,XJ3]O.4`QH_B%LJ,
MXIS]O.4`QH_B%LJ,XI3]O.4`QH_B%LJ,XHS]O.4`QH_B%LJ,XH3]O.4`QH_B
M%LJ,XGS]O.4`QH_B%LJ,XG3]O.4`QH_B%LJ,XFS]O.4`QH_B%LJ,XF3]O.4`
MQH_B%LJ,XES]O.4`QH_B%LJ,XE3]O.4`QH_B%LJ,XDS]O.4`QH_B%LJ,XD3]
MO.4`QH_B%LJ,XCS]O.4`QH_B%LJ,XC3]O.4`QH_B%LJ,XBS]O.4`QH_B%LJ,
MXB3]O.4`QH_B%LJ,XAS]O.4`QH_B%LJ,XA3]O.4`QH_B%LJ,X@S]O.4`QH_B
M%LJ,X@3]O.4`QH_B%LJ,XOS\O.4`QH_B%LJ,XO3\O.4`QH_B%LJ,XNS\O.4`
MQH_B%LJ,XN3\O.4`QH_B%LJ,XMS\O.4`QH_B%LJ,XM3\O.4`QH_B%LJ,XLS\
MO.4`QH_B%LJ,XL3\O.4`QH_B%LJ,XKS\O.4`QH_B%LJ,XK3\O.4`QH_B%LJ,
MXJS\O.4`QH_B%LJ,XJ3\O.4`QH_B%LJ,XIS\O.4`QH_B%LJ,XI3\O.4`QH_B
M%LJ,XHS\O.4`QH_B%LJ,XH3\O.4`QH_B%LJ,XGS\O.4`QH_B%LJ,XG3\O.4`
MQH_B%LJ,XFS\O.4`QH_B%LJ,XF3\O.4`QH_B%LJ,XES\O.4`QH_B%LJ,XE3\
MO.4`QH_B%LJ,XDS\O.4`QH_B%LJ,XD3\O.4`QH_B%LJ,XCS\O.4`QH_B%LJ,
MXC3\O.4`QH_B%LJ,XBS\O.4P0"WI)-!-XAP`C>48$(WE%""-Y1@0C>(4((WB
M'`"-XN1!G^6G___KX#&?Y01`C^`#,)3G##"-Y=0QG^4,()WE`S"4YP(0H.$#
M`*#A$#"-Y5?__^N\,9_E`S"4YP!0T^6T,9_E``!5XP-`E.<+```:=O__ZZ0A
MG^4``%#C`B"/X!``@N4!```:`0"@XY;__^NG___K``"4Y<#__^M]5\#E``"4
MY;W__^O.,]#E`C"#X\XSP.4``)3EN/__Z\XST.4!,(/CSC/`Y1P`G>4%`(#B
M!P%PXP```)IQ___K``&@X8W__^L`$*#A&,"=Y3`QG^4`()SE`S"/X``@@.4D
M(9_E"`"#Y0(@C^`$((#E&"&?Y0(@C^``()+E"""`Y0PAG^4"((_@#""AY00@
MH.,$((/E`3"@XQP@G>4#`%+A+@``R@`PH.,-$8+BY%"?Y0$Q@.?@$)_E`#"-
MY050C^``,*#A`R""XA``E>4!$(_@*/__ZP!`4.("```:$`"5Y6#__^L`0*#A
ML%"?Y050C^`0`)7E/?__ZZ0`G^4``(_@TP``ZP``4.,,```:##"5Y0``4^,#
M```:B`"?Y0``C^#+``#K#`"%Y7PPG^4#,(_@#`"3Y0``4.,````*UP8`ZV@P
MG^4#,(_@$`"3Y77__^O,_O_K!`"@X230C>(P@+WH`^&<YP$P@^($X*'ERO__
MZO!J`0!$`0``0`$``!`!```D`0``0&P!`,AK`0!K+0``C&L!`%(M``!D:P$`
MS`@``#1K`0#C*@``>"H``/1J`0#<:@$``+"@XP#@H.,0$)_E`1"/X`T`H.$/
MP,#C#-"@X0```.O09P$`'T`MZ4@PG^5(()_E`S"/X`(@D^<(((WE/""?Y0(@
MD^<,((WE`""@XP0@C>4L()_E`C"3YP0@@.(`,(WE`!"0Y0@PG>4,`)WE]?[_
MZQ30C>($\)WDG&@!`"`!```(`0``%`$``"P`G^4L,)_E``"/X`,PC^```%/A
M(#"?Y0,PC^`>_R\!&""?Y0(PD^<``%/C'O\O`1/_+^'`:0$`O&D!`"QH`0`<
M`0``.`"?Y3@0G^4``(_@`1"/X``00>"A/Z#A01&#X"0PG^7!$+#A`S"/X![_
M+P$8()_E`C"3YP``4^,>_R\!$_\OX7QI`0!X:0$`W&<!`#@!``!H,)_E$$`M
MZ0,PC^``,-/E7$"?Y0``4^,$0(_@$("]&%`PG^4#,)3G``!3XP(```I$,)_E
M`P"?Y\K^_^O*___K.#"?Y0,PE.<``%/C`@``"BP`G^4``(_@:_[_ZP$@H.,@
M,)_E`S"/X``@P^40@+WH+&D!`)AG`0`P`0``Q&@!`!@!``!(90``T&@!`#0P
MG^4T()_E`S"/X`(PD^<``%/C!P``"A!`+>D@$)_E(`"?Y0$0C^```(_@K?[_
MZQ!`O>BZ___JN?__ZAQG`0`T`0``B&@!`.AD``"<,)_E\$<MZ0!04.(#,(_@
M!4"@`2````J(()_E`C"3YP!`D^4``%3C&P``"@&0H.$%,*#A`V"@X0$@T^0`
M`%+C/0!2$_K__QH$@*#A!6!&X`APH.$$H)CD``!:XPI`H`$-```*!B"@X040
MH.$*`*#A4_[_ZP``4./T__\:!C#:YST`4^/Q__\:!'!'X$=QH.$!0(;B`'")
MY01`BN`$`*#A\(>]Z,QF`0`H`0``!T`MZ4@@G^5(,)_E`B"/X`,PDN<-$*#A
M`#"3Y00PC>4`,*#CRO__ZRP@G^4D,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``
M```*JO[_ZPS0C>($\)WD(&8!`"P!``#\90$`<T`MZ8P@G^6,,)_E`B"/X`,P
MDN<`0*#A`#"3Y00PC>4`,*#C#6"@X7!0G^4%4(_@!A"@X00`H.&M___K``!0
MXP@``!I8()_E3#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@"@``"HO^_^LX,)_E
M`""=Y0,PE><`,)/E`C&#X`0@D^4``%+C!""#Y/O__QKG___J"-"-XG"`O>C`
M90$`+`$``*!E`0"`90$`*`$``/!'+>D\(9_E/#&?Y0(@C^`#,)+GH-!-X@!0
M4.(`,)/EG#"-Y0`PH.,3```*`##5Y0``4^,0```*M/W_ZP!@4.(-```*!'&?
MY02!G^4$D9_E!W"/X`B`C^`)D(_@!@"@X=']_^L`0%#B#```&@8`H.'K_?_K
M!0"@X3'^_^O8()_EQ#"?Y0(@C^`#,)+G`""3Y9PPG>4"(#/@*```"E+^_^L3
M0(3B!Q"@X00`H.&[_?_K``!0X^C__PH($*#A!`"@X;;]_^L``%#CX___"@4`
MH.%"_O_K`*"@X00`H.$__O_K``"*X`(`@.+!_?_K`*"@X00PH.$%(*#A"1"@
MX2O^_^L-$*#A"@"@X1#^_^L!`'#C"@"@X0<```H0,)WE#SH#X@$)4^,#```:
MM/__ZPH`H.$/_O_KR/__ZJK]_^OZ___JH-"-XO"'O>@490$`+`$``)LE``"6
M)0``E24``)QD`0`00"WIA""?Y80PG^4"((_@H-!-X@,PDN<-$*#A`$"@X0`P
MD^6<,(WE`#"@X_O]_^L``%#C``"@$PD``!H0,)WE#SH#X@H*4^,!"5,3!```
M&@(0H.,$`*#A8_W_ZQ`/;^&@`J#A+""?Y20PG^4"((_@`S"2YP`@D^6<,)WE
M`B`SX`````H`_O_KH-"-XA"`O>BT8P$`+`$``%1C`0#P3RWI`5"@X<`AG^7`
M,9_E`B"/X`,PDN<4T$WB`#"3Y0PPC>4`,*#C`##1Y0!@H.$]`%/C`5"!`@4`
MH.'H_?_K"!"-X@!PH.$&`*#A_O[_ZX"1G^4`0%#B"9"/X!````K?_?_K``!7
MX24``(H!0$3B`3#5Y```4^,!,.3E^___&E0AG^5(,9_E`B"/X`,PDN<`()/E
M##"=Y0(@,^!)```*TOW_ZS0QG^4#H)GG`+":Y00QF^<``%/C,P``&B`QG^4"
M@(3B`S"/X``@D^4(@:#A``!2XRX```H($*#A"P"@X13]_^L``%#C``"*Y>/_
M_PH`,)KE"("#X``PH.,$,`CE"$"-Y08PH.$#`*#A`2#3Y```4N,]`%(3^O__
M&KPPG^4&`$#@`T"9YP)PA^('`(#@")"=Y0"`E.4N_?_K``!0XPD!B.?-__\*
M`#"4Y0@@G>4"(9/G`1#6Y`(PH.$``%'C/0!1$P`0PN4!((+B^/__&CT@H.,`
M(,/E`2#5Y```4N,!(./E^___&KS__^H!0(3BQO__Z@$@H.,(`*#A`""#Y13]
M_^L`,%#B!#"-Y;/__PH+$*#A""!(XA']_^L$,)WE`#"*Y<G__^H4T(WB\(^]
MZ!1C`0`L`0``S&(!`)QB`0`H`0```&0!`!-`+>D\0)_E/#"?Y01`C^`#,)3G
M``"3Y6C]_^LL,)_E+!"?Y0,PE.<!$(_@!#"-Y2`PG^4$()WE`S"/X`C0C>(0
M0+WH5_W_ZC!A`0`D`0``/`$``.<A``#"7@``$T`MZ4PPG^5,()_E`S"/X`)`
MD^<``)3E4?W_Z^#__^L``)3E3OW_ZP`@H.,L,)_E!""-Y2@0G^4H()_E`S"/
MX``PC>4"((_@`1"/X+3\_^L(T(WB$("]Z-1@`0`D`0``]B,``(<A```H#P``
M<$`MZ2P1G^4L(9_E`MI-XAC03>(!$(_@`B"1YP(ZC>(4,(/B`""2Y0`@@^4`
M(*#CK/S_ZP0AG^4$89_E`B"/X``@C>7\()_E#$"-X@`PH.$&$*#A!`"@X0(@
MC^"2_/_K`3"`X@8`4^$```":\`#PYP$`<.,+```:`#"@X\@`G^6T$)_E``"/
MX`(JC>(!$)#G%"""X@``D>4`$)+E```QX"````HE_?_K`5J-XA!0A>($`*#A
M`2J@XP40H.'1_/_K`$!0XNO__[H!`(3BG?S_ZP`P4.+G__\*!0!3X0(``"H$
M((/@`@!5X=___SH%`%/A`@``F@0@A>`"`%/AVO__.@8`5.'8___*!""@X0,`
MH.$%$*#A_?S_ZP`@H.,`,*#A!"#`Y]3__^H#`*#A`MJ-XAC0C>)P@+WH8&`!
M`"P!``!((0```1```"`A``#P7P$`JO__ZO!/+>D!4*#A[!&?Y>PAG^5"W4WB
M`1"/X#303>(`0*#AW`&?Y0(@D>="/8WB``"/X"PP@^(`()+E`""#Y0`@H.,K
M_O_K+Q"@XP!@H.$$`*#AA?S_ZP``4.,.```*I`&?Y000H.$``(_@X_[_ZY@1
MG^6((9_E`1"/X$(]C>("()'G+#"#X@`0DN4`()/E`1`RX%4```K4_/_K!`"@
MX<_\_^MH$9_E#`"-Y0$0C^`%`*#AN/S_ZP!PH.%4D9_E5*&?Y52QG^4)D(_@
M"J"/X`NPC^```%?CX/__"@`@U^4``%+C"7"@`0``5N,)```*!Q"@X08`H.$I
M_/_K``!0XP0``!H8$9_E`1"/X*+\_^L`<*#A[O__Z@<`H.&P_/_K`,"@XP``
MA^`'$$#@`2!PY2\`4N,1```*##"=Y0$@@^(!((+@`0I2X\3__ZJP@(WB!%!(
MX@<PH.$*(*#A`1J@XP4`H.$$0(WE`+"-Y?K[_^L!`(#B`0I0XP(``)KP`/#G
M`,#`Y>?__^H%`*#A$!"-XF_\_^L``%#C$```&I`P&.4/.@/B`@E3XPP``!H!
M$*#C!0"@X>7[_^L``%#C!P``&F``G^4%$*#A``"/X(O^_^L%`*#A%OS_ZP!`
MH.&C___J1!"?Y0``H.,!$(_@QO__Z@0`H.%"W8WB--"-XO"/O>@,7P$`+`$`
M``@@``#9'P``K%X!`*(?```G'P``4"```(`?``!&'P``>1X``&8>````,*#A
M`2#3Y```4N,>_R\!+P!2XP,`H`'Y___J$$`MZ0!`4.("```*`##4Y0``4^,#
M```:V`"?Y0``C^`00+WH[_O_ZEK\_^L!`$#B``"$X```5.$`,*#A&P``*@`@
MT^4!`$#B+P!2X_C__PH#`%3A%0``*@,@H.$!$%+D+P!1XP\``!H!,$/B`P!4
MX0,@H.$#```J`!#2Y0$P0^(O`%'C^/__"@0@0N`",(+B`0I3XQ4``(H!((+B
M`0I2XPP``)KP`/#G`C"@X>?__^H#`%3AZ___&@`PU.4O`%/C-`"?!0``CP#4
M__\*+`"?Y0``C^#1___J)#"?Y000H.$#,(_@`P"@X>+[_^L0@+WH``"@XQ"`
MO>B''0``WQP``#0=``"L70$`$$`MZ<`AG^7`,9_E`B"/X"C03>(#,)+G#2"@
MX;`1G^4`,)/E)#"-Y0`PH.,!$(_@"C"!XBK`@>("X*#A``"3Y000D^4(,(/B
M`P"NZ`P`4^$.(*#A]___&K`PT^%T`9_EL##.X0``C^!E_?_K:`&?Y6A!G^4`
M`(_@8?W_ZV`!G^4$0(_@``"/X%W]_^M4`9_E``"/X%K]_^M,`9_E``"/X%?]
M_^M$`9_E``"/X%3]_^L\`9_E``"/X%']_^LT`9_E``"/X$[]_^L$`*#A3/W_
MZR0!G^4``(_@2?W_ZQP!G^4``(_@1OW_ZQ0!G^4``(_@*_W_ZP`04.(!```*
M!`"@X>G]_^O\`)_E``"/X"3]_^L`$%#B`@``"NP`G^4``(_@X?W_Z^0`G^4`
M`(_@'/W_ZP`04.(0```*U`"?Y0``C^#9_?_KS!"?Y<P`G^4!$(_@``"/X-3]
M_^O`()_E;#"?Y0(@C^`#,)+G`""3Y20PG>4"(#/@$@``"L?[_^N@`)_E``"/
MX`;]_^L`$%#BE`"?%0``CQ#I__\:C!"?Y0H@H.,!$(_@$0"-XD/[_^L``%#C
MX___&G0`G^4;$(WB``"/X-[__^HHT(WB$("]Z,1;`0`L`0``8ED``)H<``"3
M'```Q1P``(L<``"('```@QP``(<<```P'```>QP``'L<```-'```;1P``&(<
M``!9&P``5!P``*@;``!<'```SQL``'!:`0`,'```JQL``/T;``!_&P``$$`M
MZ4PPG^4#,(_@`#"3Y0$`<^,,```:/`"?Y0``C^#2_/_K``!0XP0```H``-#E
M,`!0XP``4!,!`*`3``"@`Q@PG^4#,(_@``"#Y1`PG^4#`)_G$("]Z.!:`0#K
M&@``I%H!`)A:`0`00"WI@/O_ZR+[_^L``%#C``"0%1"`O>CW0"WIF'"?Y0!`
MH.$'<(_@!P"@X;7\_^L`4%#B!!"@X0(```H`,-7E``!3XP0``!IP`)_E``"/
MX`S0C>+P0+WH;/W_ZO[Z_^L``%#C$@``&@0`H.%@^__K`&"@X04`H.%=^__K
M``"&X`(`@.+?^O_K`&"@X3`PG^4P$)_E!""@X0$0C^``4(WE`S"/X$;[_^L&
M$*#A!P"@X>;__^H,T(WB\("]Z.H:``#"&@``OAD``)0:``#P3RWI:!:?Y6@F
MG^6!W$WB)-!-X@$0C^!<QI_E`B"1YX$\C>(23HWB#,"/X``@DN4<((/E`""@
MXQPP@^(04(SB=#!$XES@1.(`8*#A!P"<Z0<`@^@/`+7H#P"NZ`,`E>AH,$3B
M*,",X@,`CN@'`)SH!P"#Z`0&G^4$=I_E``"/X&W\_^L`4%#B!W"/X!,```H`
M,-7E``!3XQ````JJ___KX!6?Y<PEG^4!$(_@@3R-X@(@D><<,(/B`!"2Y0`@
MD^4!$#+@````"AG[_^L%`*#A@=R-XB30C>+P3[WHI?K_ZI/__^L`4%#B:(!$
M`F4```H%`*#A"_O_ZX``H.$!`(#BC?K_ZP"0H.$`@*#A>*6?Y0%01>(*H(_@
M`2#UY0``4N->```:7(!$X@10F.0``%7C#```"@4`H.$__/_K`%!0XOC__PH`
M,-7E``!3X_7__PK4_/_K``!0X_+__PH%`*#AA/K_ZP!0H.%TH$3B``!5XP4`
M`!H$@)KD``!8XU0```H`,-CE``!3XTD``!H%`*#AY/K_ZP"@H.$)`*#AX?K_
MZP``BN`!JX#B!*"*X@H`H.%A^O_K`("@X=`TG^70%)_E`S"/X``PC>7(-)_E
M!2"@X0,PC^`!$(_@!)"-Y<7Z_^L'':#C"`"@X;#Z_^L!`'#C.0``&JKZ_^L`
M,)#E$0!3XS4```J0))_ED!2?Y0(`E^<`,(WE`""6Y0@PH.$``)#E`1"/X(;Z
M_^L`4*#C<!2?Y4`DG^4!$(_@@3R-X@(@D><<,(/B`!"2Y0`@D^4!$#+@G/__
M&@4`H.&!W(WB)-"-XO"/O>CT^__K`#!0X@4```H`,-/E``!3XP(```H]^O_K
M`%!0XIG__QH$`)CD``!0X_/__QH,5)_E!5"/X)/__^H(`*#A"A"@X9+Z_^L"
M@(CBF/__Z@@`H.%Z_/_K``!0XZO__PH(`*#A*OK_ZP!0H.&E___J"%"@X:O_
M_^H(`*#A$!"-XG?Z_^L`D%#B"```"J0SG^6P$Y_E`P"7YP`@EN4(,*#A`1"/
MX```D.5,^O_KQ/__Z@`Q%.4/.@/B`0E3X_+__QKX4!3EA/K_ZP``5>'N__\:
M`#$4Y8,[H.&C.Z#A!PU3X^G__QH*`*#A^OG_ZP!0H.%4`Y_E``"/X+;[_^L`
M`%#C80``&@!PEN4'`*#A;/K_ZP,`4.,`H*#A&@``FBP3G^4$`$#B`1"/X```
MA^#4^?_K``!0XQ,``!H$`%KC`P``"@J@A^`%,%KE+P!3XPT``!H$8);E``!6
MXPH```H&`*#A5_K_ZP,`4.,&``":X!*?Y00`0.(!$(_@``"&X,#Y_^L``%#C
M!G"@`;;^_^L`H%#B=0``&@H0H.$'`*#AW_G_ZP!@4.)P```*`I"@XP`PX.,1
M(.#C`)"-Y01P1.*J^?_K!B"@XP<0H.$&`*#A#_K_ZP0P5.4``%/C,P``&@,P
M5.5#`%/C,```&@(P5.5!`%/C+0``&@$P5.5#`%/C*@``&@`PU.5(`%/C)P``
M&@$PU.5%`%/C)```&@`PX.,Y(.#C!@"@X0"0C>6/^?_K*2"@XP<0H.$&`*#A
M]/G_ZP@@H.$0,I_E$!*?Y0,PC^`$,(WE"#*?Y0!PC>4#,(_@`1"/X`4`H.$*
M^O_K"`"@X?GY_^OL`9_E!1"@X0``C^`7_/_K!0"@X9?^_^M.___J`'"6Y9_Y
M_^L`$*#A!P"@X1#]_^L`<%#BE___&I7__^H`,*#C`""@XP`PC>4&`*#A`#"@
MXVGY_^M"!`#K`)"@X0(IH.,'$*#A!@"@X<SY_^L`(%#B'0``R@8`H.%$8$3B
MP?G_ZS!P1.()$*#A!@"@X9D$`.L'D*#A7+&?Y0NPC^`'`*#A"Q"@X0$@UN0!
MH(KBW/G_ZQ0`6N,"<(?B]___&@`PH.,(,$3E,#&?Y3`1G^4#,(_@!#"-Y2@Q
MG^4((*#A`)"-Y0,PC^`!$(_@P/__Z@<0H.$)`*#A+@0`Z]?__^H$$9_E!`&?
MY0$0C^```(_@U_O_ZSSY_^OT,)_E]!"?Y0,PC^`)`(WH[#"?Y0@@H.$%`*#A
M`S"/X`$0C^"Y^?_KV$"?Y=A@G^78<)_E!$"/X`9@C^`'<(_@!QV@XP4`H.&>
M^?_K`0!PXZ/__QJ8^?_K`#"0Y1$`4^.?__\:(OG_ZP&0B>(!`HWH!#"@X0@@
MH.$&$*#A!0"@X0APC>6A^?_K[/__ZE18`0`L`0``C%D!```9``#@5P$`P%<!
M`$49``"G&```BA@``,07```,`0``3!@``#16`0"Z%P``HQ<``/46``!R%P``
M)Q<```X7``!$%@``V!0``*`4``#M%```&A8``$P5``#@$P``:!0``/<3``#*
M%0``"Q4``)`3``!X$P```14``)85``#W3RWI-#.?Y30CG^4#,(_@`D"3YP``
ME.5T^?_K`%"@X0``E.5Q^?_K9##5Y64PP.40`Y_E``"/X,#Z_^L``%#C!0``
M"@`PT.4Q`%/C`@``&@$PT.4``%/C````"D[]_^L``)3E8?G_Z]P2G^4+,*#C
M`2"@XP$0C^`+^?_K``!0XQX``!H``)3E6/G_Z[P2G^4#,*#C`2"@XP$0C^`"
M^?_K`%!0XDT``!H``)3E3_G_ZYP2G^4#,*#C`2"@XP$0C^#Y^/_K`%!0XF$`
M``J$`I_E``"/X)GZ_^L`(%#B!""-Y5````H``)3E0/G_ZPPPE>4$()WE`!"3
MY?'X_^M4``#J`5"@XPPPD.5,DI_E&'"3Y4BBG^4)D(_@!#"9Y0``E.4%`%/A
M`8!%X@8``-HO^?_K`#"@XP@@H.$'$*#AL_C_ZP!@4.('```:%&*?Y09@C^`$
M,);E`3!#X@,`6.'(__\:`5"@XQ@``.H(,)GE`""6Y06QD^<(,)+E"C`#X`$+
M4^,,$)(%!@``"@``E.47^?_K`!"6Y0(PH.,`(*#C'_G_ZP`0H.$+`*#AC_C_
MZP``4./D__\:`5"%XM;__^H+^?_K!Q"@X6?X_^L!4(7B!#"6Y0``E.4%`%/A
M]___RJC__^H``)3E`?G_ZPPPE>5T(9_E`!"3Y0(@C^"Q^/_K##"5Y0`PD^4(
M,)/E`043XZ7__PH``)3E]?C_ZPPPE>4`$)/E@/C_ZY___^JR^__K`&!0X@``
ME.4H```*[/C_ZPPPE>4&(*#A`!"3Y9WX_^L&`*#AVOC_ZP``E.7D^/_K`%"@
MX0``E.7A^/_K_!"?Y0$@H.,!$(_@1/C_Z_`@G^4`$*#A`B"/X`4`H.&-^/_K
M``"4Y=;X_^L`,*#C93#`Y=``G^700)_E``"/X"3Z_^L$0(_@``!0XPP`A.4.
M```:"`"4Y8_]_^L``%#C#`"$Y0D``!JD`)_E``"/X#?X_^O#^/_KF#"?Y0,P
MC^`(()/E##"5Y0`@DN5^___JA$"?Y0<=H.,$0(_@#`"4Y:GX_^L!,(#B$0!0
MXP$`4Q,&``":`#"@X0@0E.5<`)_E#""4Y0`0D>4``(_@(/C_ZPS0C>+PC[WH
M8%$!`"0!``"'$@``PA,``*,3``"?$P``N1$``/A1`0``!"``P%$!`$D2``#2
M$0``UQ$``-P/``!@4`$`B1$``"A0`0`,4`$`3A$``'!`+>D`0*#A/OS_ZS;\
M_^L`4*#A"OW_ZP``4.,``%03<("]"``PU.4``%/C<("]"!P0G^4%`*#A`1"/
MX#'X_^L``%7A<("]&`0`H.%P0+WH&OK_ZJ</``#P3RWI,"N?Y3`[G^4"((_@
M4]]-X@,PDN<$((WB`L"@X0`PD^5$,8WE`#"@XUS@@.(<,(#B!!"3Y#$?O^8#
M`%[A!!",Y/K__QI`P*#C`A"@X2#@D>4T,)'E!"""X@XP(^`(X)'E`!"1Y0XP
M(^`!,"/@XS^@X0'`7.(\,(+E\O__&KPZG^4$D)WE$&"0Y0@@G>6`0)#HV$#`
MX0.0B>`%P"3@;A$DX`<0`>`#((+@!I")X`[`#.#GG8G@!<`LX`4@@N`$$"'@
M#)")X`(0@>!GP:#A#""=Y6ZA+.`)H`K@`R""X!"`G>4$((+@;J$JX.D=@>`"
MH(K@:2$LX`$@`N`#@(C@X:V*X!2PG>5A$:#A#"`BX&Z!B.`(((+@:8$AX`.P
MB^`*@`C@#,"+X&F!*.`8L)WEZBV"X`R`B.!JP2'@`["+X`+`#.#BC8C@:9&+
MX&(AH.$<L)WE`<`LX`G`C.!JD2+@`["+X`B0">`!$(O@:I$IX""PG>7HS8S@
M`9")X&@1(N`#L(O@#!`!X.R=B>!JH8O@;,&@X22PG>4"$"'@"A"!X&BA+.`#
ML(O@":`*X`(@B^!HH2K@*+"=Y>D=@>`"H(K@:2$LX`.PB^`!(`+@X:V*X&B!
MB^!A$:#A++"=Y0P@(N`(((+@:8$AX`.PB^`*@`C@#,"+X&F!*.`PL)WEZBV"
MX`R`B.!JP2'@`["+X`+`#.!ID8O@`<`LX.*-B.`)P(S@8B&@X320G>5JL2+@
M`Y")X`BP"^`!$(G@:K$KX#B0G>7HS8S@`;"+X&@1(N`#D(G@#!`!X.R]B^!J
MH8G@;,&@X3R0G>4"$"'@"A"!X&BA+.`#D(G@"Z`*X`(@B>!HH2K@0)"=Y>L=
M@>`"H(K@:R$LX`.0B>`!(`+@X:V*X&B!B>!A$:#A1)"=Y0P@(N`(((+@:X$A
MX`.0B>`*@`C@:X$HX`S`B>`,P(C@2("=Y>HM@N!JD2'@`X"(X`*0">!KL8C@
M`9`IX.+-C.`+D(G@8B&@X4RPG>5J@2+@`["+X`R`".!J@2C@`1"+X%"PG>7L
MG8G@`1"(X&R!(N`#,(O@"8`(X&JA@^`"@"C@&#B?Y0J`B.!4H)WEZ1V!X`.@
MBN!ID:#A`B"*X&RA*>`!H"K@"B""X%B@G>7AC8C@`Z"*X&S!BN!AH2G@"*`J
MX`K`C.!<H)WEZ"V"X`.@BN!H@:#A"9"*X&&A*.`"H"K@"I")X&"@G>7BS8S@
M`Z"*X&$1BN!BH2C@#*`JX`H0@>!DH)WE[)V)X`.@BN!LP:#A"("*X&*A+.`)
MH"K@"H"(X&B@G>5LL)WE`Z"*X.D=@>!B(8K@::$LX.&-B.`!H"K@`["+X&$1
MH.$,P(O@:;$AX`BP*^`+L(S@<,"=Y0H@@N`#P(S@=*"=Y>@M@N!IP8S@:)$A
MX.*]B^`"D"G@`Z"*X&(AH.$!$(K@:*$BX`N@*N`*H('@>!"=Y0G`C.`#$('@
M?)"=Y>O-C.!H$8'@:X$BX.RMBN`,@"C@`Y")X&S!H.$"((G@:Y$LX`J0*>`)
MD(+@@""=Y0@0@>`#((+@A("=Y>H=@>!K(8+@:K$LX.&=B>`!L"O@`X"(X&$1
MH.$,P(C@:H$AX`F`*.`(@(S@B,"=Y0L@@N`#P(S@C+"=Y>DM@N!JP8S@::$A
MX.*-B.`"H"K@`["+X&(AH.$!$(O@:;$BX`BP*^`+L('@D!"=Y0K`C.`#$('@
MZ,V,X&D1@>!HD2+@#)`IX`D0@>"4D)WE[+V+X`.0B>!LP:#A`B")X&B1+.`+
MD"G@"9""X)@@G>6<H)WE`R""X.L=@>!H(8+@:X$LX.&=B>`!@"C@`Z"*X&$1
MH.$,H(K@:\$AX`G`+.`,H(K@H,"=Y0@@@N`#P(S@Z2V"X&O!C.!IL2'@XJV*
MX`*P*^!B(:#A:8&"X6DQ`N`*@`C@"\",X`.`B.&DL)WEH#6?Y>K-C.`#L(O@
M`1"+X`&`B.!J$8+A:K$"X`P0`>`+$('AJ+"=Y>R-B.`#L(O@;,&@X6F1B^`)
M$('@:I&,X6JQ#.`(D`G@"Y")X:RPG>7H'8'@`["+X`(@B^`"D(G@:"&,X6BQ
M#.`!(`+@"R""X;"PG>7AG8G@`["+X&$1H.%JH8O@"B""X&BA@>%HL0'@":`*
MX`N@BN&TL)WEZ2V"X`.PB^`,P(O@#*"*X&G!@>%IL0'@`L`,X`O`C.&XL)WE
MXJV*X`.PB^!B(:#A:(&+X`C`C.!I@8+A:;$"X`J`".`+@(CAO+"=Y>K-C.`#
ML(O@`1"+X`&`B.!J$8+A:K$"X`P0`>`+$('AP+"=Y>R-B.`#L(O@;,&@X6F1
MB^`)$('@:I&,X6JQ#.`(D`G@"Y")X<2PG>7H'8'@`["+X`(@B^`"D(G@:"&,
MX6BQ#.`!(`+@"R""X<BPG>7AG8G@`["+X&$1H.%JH8O@:+&!X0H@@N`)L`O@
M:*$!X`JPB^',H)WEZ2V"X`.@BN`,P(K@#+"+X&G!@>%IH0'@`L`,X`K`C.'0
MH)WEXKV+X`.@BN!B(:#A:(&*X&FA@N$(P(S@"Z`*X&F!`N`(H(KAU("=Y>O-
MC.`#@(C@`1"(X`&@BN!K$8+A:X$"X`P0`>`($('AV("=Y>RMBN`#@(C@;,&@
MX6F1B.`)$('@:Y&,X6N!#.`*D`G@")")X=R`G>7J'8'@`X"(X`(@B.`"D(G@
M:B&,X6J!#.`!(`+@""""X>"`G>7AG8G@`X"(X&$1H.%KL8C@"R""X&JQ@>%J
M@0'@";`+X`BPB^'D@)WEZ2V"X`.`B.`,P(C@:8&!X0RPB^`"@`C@:<$!X`R`
MB.'HP)WEXKV+X`/`C.!B(:#A:J&,X`J`B.!IH8+A:<$"X`N@"N`,H(KA[,"=
MY>N-B.`#P(S@`1",X&O!@N$!H(K@",`,X&L1`N`!P(SA\!"=Y>BMBN`#,('@
M:9&#X`G`C.#`,I_E])"=Y6B!H.$#D(G@`B")X/@0G>5KD2C@"I`IX`F0@N`#
M$('@_""=Y>K-C.!K$8'@:K$HX.R=B>`,L"O@`R""X&S!H.$(@(+@:B$LX`D@
M(N`"@(C@`"&=Y0L0@>`#((+@!+&=Y>D=@>!J(8+@::$LX.&-B.`!H"K@`["+
MX&$1H.$,P(O@:;$AX`BP*^`+L(S@",&=Y0H@@N`#P(S@#*&=Y>@M@N!IP8S@
M:)$AX.*]B^`"D"G@`Z"*X&(AH.$!$(K@:*$BX`N@*N`*H('@$!&=Y0G`C.`#
M$('@Z\V,X&@1@>!K@2+@#(`HX`@0@>`4@9WE[*V*X`.`B.!LP:#A`B"(X&N!
M+.`*@"C@"(""X!@AG>4<D9WE`R""X.H=@>!K(8+@:K$LX.&-B.`!L"O@`Y")
MX&$1H.$,P(G@:I$AX`B0*>`)D(S@(,&=Y0L@@N`#P(S@)+&=Y>@M@N!JP8S@
M:*$AX.*=B>`#L(O@`J`JX&(AH.$!$(O@:+$BX`FP*^`+L('@*!&=Y0K`C.`#
M$('@Z<V,X&@1@>!I@2+@#(`HX`@0@>`L@9WE[+V+X`.`B.!LP:#A`B"(X&F!
M+.`+@"C@"(""X#`AG>7K'8'@`R""X&DA@N!KD2S@`9`IX`D@@N`TD9WEX8V(
MX`.0B>!A$:#A#,")X&N1(>`(D"G@"<",X#B1G>7H+8+@`Y")X&NQB>!HD2'@
M`I`IX`FPB^`\D9WEXLV,X`.0B>!B(:#A`1")X&B1(N`,D"G@"1"!X$"1G>7L
MO8O@`S")X`=P@^!H@8?@;'$BX`MP)^`"((;@ZQV!X!`@@.4'@(C@7""?Y>&-
MB.!`,)_E`1".X&NQA.!LP87@`B"/X`"`@.4$$(#E"+"`Y0S`@.4#,)+G`""3
MY40QG>4"(#/@````"L?U_^M3WXWB\(^]Z'Q-`0`L`0``F7F"6J'KV6[<O!N/
MUL%BRH!"`0`00"WI8`"@XSWU_^LH$)_E*""?Y2C`G^4HX)_E!E"`Z"0@G^40
M((#E`""@XQ0@@.48((#E7""`Y1"`O>@!(T5GB:O-[_[<NIAV5#(0\.'2P_!!
M+>D"8*#A%#"0Y8(AH.$",)/@&""0)10P@.4!(((B&""`)1@PD.4`4*#AICZ#
MX!@P@.5<,)#E''"`X@``4^,9```*0$!CX@0`5N$#`(?@!D"@L0$`4.$#```J
M!#"`X`,`4>$````J\`#PYP$`4.$$@('@`0``F@@`4.'Y__\Z!""@X7SU_^M<
M,)7E`S"$X$``4^-<,(7E\(&]&`4`H.'L_/_K"!"@X01@1N!<@(7B/P!6XPX`
M`,H'`%'A`@``F@8PA^`#`%'AYO__.@<`4>$"```J!C"!X`,`5^'A__\Z!B"@
MX0<`H.%C]?_K7&"%Y?"!O>@'`%'A`0``F@@`4>'8__\Z`0!7X4`P@>(!``":
M`P!7X=/__SH!0*#A!R"@X000E.0#`%3A!!""Y/O__QH%`*#AQ_S_ZT!@1N($
M$*#AVO__ZO!!+>D<@('B%#"1Y1A@D>4!0*#A?Q#@XS-_O^:C,:#A/S`#X@$@
M@^(X`%+C`%"@X0,0R.<"`(C@`!"@TS9OO^8X(&+2!P``V@`0H.-`(&+BO?3_
MZP0`H.&M_/_K.""@XP`0H.,(`*#AM_3_ZP0`H.'T9<3AIOS_ZP,PU.4$`*#A
M`##%Y;(PU.$!,,7E`#"4Y2,TH.$",,7E`#"4Y0,PQ>4',-3E!##%Y;8PU.$%
M,,7E!#"4Y2,TH.$&,,7E!#"4Y0<PQ>4+,-3E"##%Y;HPU.$),,7E"#"4Y2,T
MH.$*,,7E"#"4Y0LPQ>4/,-3E###%Y;XPU.$-,,7E##"4Y2,TH.$.,,7E##"4
MY0\PQ>43,-3E$##%Y;(QU.$1,,7E$#"4Y2,TH.$2,,7E$#"4Y1,PQ>7P0;WH
M[?3_Z@%`+>D!0+WH'O\OX2]T;7``4$%27U1-4$1)4@!414U01$E2`%1-4`!5
M4T52`%5315).04U%`"XN`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO
M861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E<P!E>&4`4$%2
M7U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU
M3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,
M14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?
M1TQ/0D%,7U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!
M3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0051(`%-94U1%30`E,#)X`"5S
M)7,E<R5S`'!A<BT`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E
M<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`4$%2
M.CI086-K97(Z.E9%4E-)3TX`,2XP-3``56YA8FQE('1O(&-R96%T92!C86-H
M92!D:7)E8W1O<GD`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`M90`M+0!E=F%L("=E
M>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N
M;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P[
M"FUY("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I
M;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T
M96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@
M<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP
M.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@
M)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G
M+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-5
M1D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C
M(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N
M("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE
M;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL
M(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI
M=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O
M;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[
M)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/
M4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O
M9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A
M=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E
M;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*
M;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S
M:7IE(#T@-C0@*B`Q,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@
M)&-H=6YK7W-I>F4I('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D
M;2`]("1S:7IE("4@)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@
M)'-I>F4@+2`D;3L*?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H
M=6YK7W-I>F4["GT*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K*%]&
M2"P@)&UA9VEC7W!O<RP@,"D["G)E860H7T9(+"`D8G5F+"`D8VAU;FM?<VEZ
M92`K(&QE;F=T:"@D4$%27TU!1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD97@H
M)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*
M;&%S=#L*?0HD;6%G:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@
M)&UA9VEC7W!O<R`\(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*
M<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M
M('5N<&%C:R@B3B(L("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*
M;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]
M("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI
M*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB
M+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M
M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]
M/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@
M0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE
M=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%2
M7T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D
M9F@I.PIP<FEN="`D9F@@)&EN9F\M/GMB=69].PIS965K*"1F:"P@,"P@,"D[
M"G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL
M92@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D
M9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA
M;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O
M='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]
M+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/
M.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q
M=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP
M;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL
M96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD
M+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S
M="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*
M?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C
M86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N
M:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE
M="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO
M="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE
M7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*
M?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P
M87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G
M*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV
M(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT
M<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE
M=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI
M)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO
M9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@
M/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!
M5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.
M0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD
M969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@
M7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M
M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K
M97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG
M(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?
M7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L
M;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@
M>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R
M:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U
M:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G
M<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@
M;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E
M9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E
M9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG
M.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T
M(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY
M("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D
M9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q
M+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#
M8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A
M8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0[
M"GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B
M)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R
M968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T
M<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M
M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@
M*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS
M92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@
M)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X[
M"F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C
M;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F
M:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*
M)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S
M(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M
M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI
M.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE
M2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!
M+3YN97<H,2D["F]P96XH;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F
M:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA
M;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X
M("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#
M04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP
M<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U
M=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A
M=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL
M("=R)RD@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`[
M"B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%2
M7U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*
M9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I
M9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE
M;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH
M/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*
M;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ
M4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D[
M"FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP
M<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M
M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D[
M"GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T
M;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@
M97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P
M(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP
M87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@
M<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P
M(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE
M*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE
M+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N
M86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T
M:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D
M:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER
M92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR
M97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S
M.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF
M:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ
M2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE
M=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z
M.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T
M('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T[
M"F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA
M<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E
M;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*
M9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U0
M1$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@
M+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD
M("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60[
M"F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[
M?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N
M86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W
M=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE
M(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*
M?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H
M)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D[
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H
M;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y
M<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I
M('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD
M8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE
M=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D
M9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE
M>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD
M14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*
M?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E
M*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL
M97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M
M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A
M;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@
M)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N
M86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL
M;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M
M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.
M5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-
M4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A
M)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O
M9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5]
M.PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF
M:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S
M("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD
M9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D
M0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@
M)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E
M9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN
M960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I
M.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N
M9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B![
M"FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N
M.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H
M<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I
M("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?
M1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A
M;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@!P97)L>'-I+F,`7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````",%P```!<```$```!6`P```0```&$#```/````
MK00```P```"`$```#0```$P_```9````P'T!`!L````$````&@```,1]`0`<
M````!````/7^_V\L`0``!0```-0(```&````%`(```H```#+!```"P```!``
M```5``````````,```"X?@$``@```/@!```4````$0```!<```"(#@``$0``
M`*`-```2````Z````!,````(````&`````````#[__]O`0``"/K__V\0````
M`````````````````````````````````````````````````````,A]`0``
M`````````(P0``",$```C!```(P0``",$```C!```(P0``",$```C!```(P0
M``",$```C!```(P0``",$```C!```(P0``",$```C!```(P0``",$```C!``
M`(P0``",$```C!```(P0``",$```C!```(P0``",$```C!```(P0``",$```
MC!```(P0``",$```C!```(P0``",$```C!```(P0``",$```C!```(P0``",
M$```C!```(P0``",$```C!```(P0``",$```C!```(P0``",$```C!```(P0
M``",$```C!```(P0``",$```C!```(P0``",$```C!```)03````````````
M`$P_`````````````(`0````````````````````````````````````````
M````````````@`$`_____U@_``"#/P```````%T_``!=0```:#\``&]```!P
M/P```````'0_``!Y/P```````!%"``!'0T,Z("A!;'!I;F4@,3`N,BXP*2`Q
M,"XR+C``03(```!A96%B:0`!*`````4V6DL`!@<(`0D!"@(2!!,!%`$5`1<#
M&`$:`AP!'@0B`40!`"YS:'-T<G1A8@`N:6YT97)P`"YG;G4N:&%S:``N9'EN
M<WEM`"YD>6YS='(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I
M;FD`+G)O9&%T80`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`
M+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB
M=71E<P``````````````````````````````````````````````````````
M"P````$````"````%`$``!0!```8```````````````!`````````!,```#V
M__]O`@```"P!```L`0``Z`````,`````````!`````0````=````"P````(`
M```4`@``%`(``,`&```$`````P````0````0````)0````,````"````U`@`
M`-0(``#+!``````````````!`````````"T````)`````@```*`-``"@#0``
MZ`````,`````````!`````@````V````"0```$(```"(#@``B`X``/@!```#
M````$`````0````(````/P````$````&````@!```(`0```,````````````
M```$`````````#H````!````!@```(P0``",$```"`,`````````````!```
M``0```!%`````0````8```"4$P``E!,``+@K``````````````0`````````
M2P````$````&````3#\``$P_```,```````````````$`````````%$````!
M`````@```%@_``!8/P``2CT``````````````0````````!9`````0````(`
M``"D?```I'P```0```````````````0`````````8P````X````#````P'T!
M`,!]```$```````````````$````!````&\````/`````P```,1]`0#$?0``
M!```````````````!`````0```![````!@````,```#(?0$`R'T``/`````$
M``````````0````(````A`````$````#````N'X!`+A^``!(`0``````````
M```$````!````(D````!`````P````"``0``@```/```````````````!```
M``````"/````"`````,````\@`$`/(```#`0``````````````0`````````
ME`````$````P`````````#R````<```````````````!`````0```)T````#
M``!P``````````!8@```,P```````````````0`````````!`````P``````
>````````BX```*T```````````````$`````````
